============
Installation
============

At the command line with pip::

    $ pip install lenstronomy

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv lenstronomy
    $ pip install lenstronomy

You can also clone the github repository for development purposes.
